#
# spec file for package python-pyFFTW
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%ifarch %{ix86} x86_64
%bcond_without  test
%else
%bcond_with     test
%endif
Name:           python-pyFFTW
Version:        0.10.4
Release:        lp151.2.4
Summary:        A pythonic wrapper around FFTW, the FFT library
License:        GPL-2.0+ and BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://hgomersall.github.com/pyFFTW/
Source:         https://files.pythonhosted.org/packages/source/p/pyFFTW/pyFFTW-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.6}
BuildRequires:  %{python_module scipy >= 0.12.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  fftw3-threads-devel
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.6
Requires:       python-scipy >= 0.12.0

%python_subpackages

%description
pyFFTW is a pythonic wrapper around the FFTW libary.
An interface for all the possible transforms that FFTW can perform is provided.

Both the complex DFT and the real DFT are supported, as well as arbitrary
axes of abitrary shaped and strided arrays, which makes it almost
feature equivalent to standard and real FFT functions of ``numpy.fft`` 
(indeed, it supports the ``clongdouble`` dtype which ``numpy.fft`` does not).

Operating FFTW in multithreaded mode is supported.

A comprehensive unittest suite can be found with the source on the github 
repository.

%prep
%setup -q -n pyFFTW-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%{python_expand find %{buildroot}%{$python_sitearch}/pyfftw/ -name "*.py" -exec sed -i "s|^#!/usr/bin/env python$|#!%__$python|" {} \; -exec grep -q "^#!%__$python$" {} \; -exec chmod a+x {} \;
$python -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/pyfftw/
$python -O -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/pyfftw/
%fdupes %{buildroot}%{$python_sitearch}
}

%if %{with test}
%check
%{python_expand $python setup.py build_ext --inplace
$python setup.py test
$python setup.py clean
}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst CHANGELOG.md LICENSE.txt
%{python_sitearch}/*

%changelog
* Sun Oct  8 2017 jengelh@inai.de
- Replace future aims in description.
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 0.10.4
  + Fixed bugs:
  * Numpy interface can fail with non-writeable arrays.
  * undefined symbol: simd\_alignment with gcc 5.3.0
  * FTBFS: TypeError: can't pickle Cython.Compiler.FlowControl.NameAssignment objects
  + Closed issues:
  * pyfftw fails with ImportError/undefined symbol fftwl\_plan\_with\_nthreads
  * pyfftw does not appear to be using available wisdom files
  * Accuracy of non-power 2 data
  * Cannot find fftw3l when installing from pip
  * Incorrect links to docs
  * PyFFTW returning all zero array after transform...
  * Move to separate pyFFTW project page
  * Release GIL during planning?
  * Merging/sharing wisdom
  * scipy interface patching.
  * very slow test suite
  * setup: some targets should not require numpy to be installed
  * 2x margin on the planning timelimit test is inadequate in windows on Complex64
* Mon Feb  1 2016 toddrme2178@gmail.com
- update to version 0.10.1:
  * it seems that pypi has an annoying feature that minor tweaks can't
    be pushed without a new release.
- changes from version 0.10.0:
  * Closed issues:
    + Conda downloads are failing
    + Python 3.4 and WinPython
    + Installing pyfftw on Anaconda3 on Windows 7
    + is python 3.5 supported?
    + deadlock of cache handler at interpreter shutdown
    + pyFFTW breaks when forked
    + build with mingw
    + Striding in n\_byte\_align not on a uniform standard
    + No exception on wrong arguments of function call of
    pyfftw.FFTW\(...\)
    + pyfftw vs numpy.fft: faster and slower
    + simple transposes?
    + `Datatype not supported` with scipy
    + Update tutorial with new byte align functions
    + OS X Installation errors:
    + Wrong results for pyfftw's ifft?
    + Installing on OS X Mavericks
    + Install error. Ld cannot find -lfftw3f
    + new source release with updated licensing
    + Crash during initialization of FFTW plan for r2c and c2r with
    Intel compiler
    + Move FFTW class definition to pyfftw.pxd
    + Provide transform metadata such as axes and direction
    + Provide shape and dtype properties
    + problem with very large arrays: OverflowError: value too large
    to convert to int
    + add support for in-place multidimensional r2c transform
    + Add numpy interface for hfft
    + add cython as a build dependency
    + Potential memory leak in caching
    + Allow GIL to be released with threads=1
    + Building for 64bit windows
    + Test failure using numpy 1.6.2
    + Remove the requirement for users to specify alignment
    + pyfftw.interfaces can only handle numpy arrays
  * Merged pull requests:
    + Release GIL during both single- and multi-thread execution
    + Support FFTW\_WISDOM\_ONLY
    + Release GIL around FFTW planning
    + Updated the tutorial to reflect changes with new aligned array
    + Add description for installing on OS X
    + close issue \#8 (More numpy like aligned array creation)
    + Discrete sine transform imports
* Sat Apr 19 2014 mardnh@gmx.de
- cleanup package
* Tue Apr 15 2014 mardnh@gmx.de
- initial package
